Western Cape Labs HTTP Services API client
=======================

A client library for the Western Cape Labs HTTP Services APIs.

Issues can be filed in the GitHub issue tracker. Please don't use the issue
tracker for general support queries.

Release Notes
-----------------------

0.1.4 - Added Worker endpoint for adding tasks and emails into the queue
0.1.5 - Added Addresses filtering for types
0.1.6 - Added Customer/PaymentMethod endpoint

